#[repr(C)]pub struct Matrix1x3 {
pub c00: Scalar,
pub c01: Scalar,
pub c02: Scalar,
}Expand description
A 1 x 3 Matrix.
Fields
c00: Scalarc01: Scalarc02: ScalarTrait Implementations
Sourceimpl AbsDiffEq for Matrix1x3
impl AbsDiffEq for Matrix1x3
Sourcefn default_epsilon() -> Self::Epsilon
fn default_epsilon() -> Self::Epsilon
The default tolerance to use when testing values that are close together. Read more
Sourcefn abs_diff_eq(&self, other: &Self, epsilon: Self::Epsilon) -> bool
fn abs_diff_eq(&self, other: &Self, epsilon: Self::Epsilon) -> bool
A test for equality that uses the absolute difference to compute the approximate
equality of two numbers.
Sourceimpl AddAssign for Matrix1x3
impl AddAssign for Matrix1x3
Sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Performs the
+= operation. Read moreSourceimpl MulAssign<f32> for Matrix1x3
impl MulAssign<f32> for Matrix1x3
Sourcefn mul_assign(&mut self, rhs: Scalar)
fn mul_assign(&mut self, rhs: Scalar)
Performs the
*= operation. Read moreSourceimpl RelativeEq for Matrix1x3
impl RelativeEq for Matrix1x3
Sourcefn default_max_relative() -> Self::Epsilon
fn default_max_relative() -> Self::Epsilon
The default relative tolerance for testing values that are far-apart. Read more
Sourceimpl SubAssign for Matrix1x3
impl SubAssign for Matrix1x3
Sourcefn sub_assign(&mut self, rhs: Matrix1x3)
fn sub_assign(&mut self, rhs: Matrix1x3)
Performs the
-= operation. Read moreSourceimpl UlpsEq for Matrix1x3
impl UlpsEq for Matrix1x3
impl Copy for Matrix1x3
impl StructuralPartialEq for Matrix1x3